@@ -8,7 +8,7 @@ use Symbol ();
 use POSIX ();
 use Config;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use constant {
     INET_ATON     => 0,
@@ -93,6 +93,8 @@ sub get_result {
 sub timedout {
     my ($self, $sock) = @_;
     
+    return if defined ${^GLOBAL_PHASE} && ${^GLOBAL_PHASE} eq 'DESTRUCT';
+    
     if (ref $sock) {
         tied(*$sock)->need_result(0);
         $sock = fileno $sock;
@@ -223,7 +225,7 @@ If it will fail to install use instructions listed below.
 
 One of the possible solution to make your perl compatible with this module is to build perl with perl threads support
 using C<-Dusethreads> for C<Configure> script. Other solution is to use C<-A prepend:libswanted="pthread ">, which will
-just link non-threaded perl with pthreads.
+just link non-threaded perl with pthreads. This is done by default since Perl 5.22.
 
 On Linux with perl not linked with pthreads this module may die with appropriate message at require time. This may happen
 if you are called some functions from system library related to DNS operations before loading of C<Net::DNS::Native> (or some module,
